return <<'END';
0041	005a
0061	007a
00aa	
00b5	
00ba	
00c0	00d6
00d8	00f6
00f8	021f
0222	0233
0250	02ad
02b0	02b8
02bb	02c1
02d0	02d1
02e0	02e4
02ee	
037a	
0386	
0388	038a
038c	
038e	03a1
03a3	03ce
03d0	03d7
03da	03f3
0400	0481
048c	04c4
04c7	04c8
04cb	04cc
04d0	04f5
04f8	04f9
0531	0556
0559	
0561	0587
05d0	05ea
05f0	05f2
0621	063a
0640	064a
0671	06d3
06d5	
06e5	06e6
06fa	06fc
0710	
0712	072c
0780	07a5
0905	0939
093d	
0950	
0958	0961
0985	098c
098f	0990
0993	09a8
09aa	09b0
09b2	
09b6	09b9
09dc	09dd
09df	09e1
09f0	09f1
0a05	0a0a
0a0f	0a10
0a13	0a28
0a2a	0a30
0a32	0a33
0a35	0a36
0a38	0a39
0a59	0a5c
0a5e	
0a72	0a74
0a85	0a8b
0a8d	
0a8f	0a91
0a93	0aa8
0aaa	0ab0
0ab2	0ab3
0ab5	0ab9
0abd	
0ad0	
0ae0	
0b05	0b0c
0b0f	0b10
0b13	0b28
0b2a	0b30
0b32	0b33
0b36	0b39
0b3d	
0b5c	0b5d
0b5f	0b61
0b85	0b8a
0b8e	0b90
0b92	0b95
0b99	0b9a
0b9c	
0b9e	0b9f
0ba3	0ba4
0ba8	0baa
0bae	0bb5
0bb7	0bb9
0c05	0c0c
0c0e	0c10
0c12	0c28
0c2a	0c33
0c35	0c39
0c60	0c61
0c85	0c8c
0c8e	0c90
0c92	0ca8
0caa	0cb3
0cb5	0cb9
0cde	
0ce0	0ce1
0d05	0d0c
0d0e	0d10
0d12	0d28
0d2a	0d39
0d60	0d61
0d85	0d96
0d9a	0db1
0db3	0dbb
0dbd	
0dc0	0dc6
0e01	0e30
0e32	0e33
0e40	0e46
0e81	0e82
0e84	
0e87	0e88
0e8a	
0e8d	
0e94	0e97
0e99	0e9f
0ea1	0ea3
0ea5	
0ea7	
0eaa	0eab
0ead	0eb0
0eb2	0eb3
0ebd	
0ec0	0ec4
0ec6	
0edc	0edd
0f00	
0f40	0f47
0f49	0f6a
0f88	0f8b
1000	1021
1023	1027
1029	102a
1050	1055
10a0	10c5
10d0	10f6
1100	1159
115f	11a2
11a8	11f9
1200	1206
1208	1246
1248	
124a	124d
1250	1256
1258	
125a	125d
1260	1286
1288	
128a	128d
1290	12ae
12b0	
12b2	12b5
12b8	12be
12c0	
12c2	12c5
12c8	12ce
12d0	12d6
12d8	12ee
12f0	130e
1310	
1312	1315
1318	131e
1320	1346
1348	135a
13a0	13f4
1401	166c
166f	1676
1681	169a
16a0	16ea
1780	17b3
1820	1877
1880	18a8
1e00	1e9b
1ea0	1ef9
1f00	1f15
1f18	1f1d
1f20	1f45
1f48	1f4d
1f50	1f57
1f59	
1f5b	
1f5d	
1f5f	1f7d
1f80	1fb4
1fb6	1fbc
1fbe	
1fc2	1fc4
1fc6	1fcc
1fd0	1fd3
1fd6	1fdb
1fe0	1fec
1ff2	1ff4
1ff6	1ffc
207f	
2102	
2107	
210a	2113
2115	
2119	211d
2124	
2126	
2128	
212a	212d
212f	2131
2133	2139
3005	3006
3031	3035
3041	3094
309d	309e
30a1	30fa
30fc	30fe
3105	312c
3131	318e
31a0	31b7
3400	4db5
4e00	9fa5
a000	a48c
ac00	d7a3
f900	fa2d
fb00	fb06
fb13	fb17
fb1d	
fb1f	fb28
fb2a	fb36
fb38	fb3c
fb3e	
fb40	fb41
fb43	fb44
fb46	fbb1
fbd3	fd3d
fd50	fd8f
fd92	fdc7
fdf0	fdfb
fe70	fe72
fe74	
fe76	fefc
ff21	ff3a
ff41	ff5a
ff66	ffbe
ffc2	ffc7
ffca	ffcf
ffd2	ffd7
ffda	ffdc
END
